PAWpySeed: Member List

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

pawpyseed.core.noncollinear.NCLWavefunction Member List

This is the complete list of members for pawpyseed.core.noncollinear.NCLWavefunction, including all inherited members.

__init__(self, struct, pwf, cr, outcar, setup_projectors=True) | pawpyseed.core.noncollinear.NCLWavefunction |
check_c_projectors(self) | pawpyseed.core.wavefunction.Wavefunction |
coords | pawpyseed.core.noncollinear.NCLWavefunction |
cr | pawpyseed.core.noncollinear.NCLWavefunction |
dim | pawpyseed.core.noncollinear.NCLWavefunction |
encut | pawpyseed.core.wavefunction.Wavefunction |
free_all(self) | pawpyseed.core.wavefunction.Wavefunction |
freed | pawpyseed.core.wavefunction.Wavefunction |
from_atomate_directory(path, setup_projectors=False) | pawpyseed.core.wavefunction.Wavefunction | static
from_directory(path, setup_projectors=True) | pawpyseed.core.noncollinear.NCLWavefunction | static
from_files(struct="CONTCAR", pwf="WAVECAR", cr="POTCAR", vr="vasprun.xml", outcar="OUTCAR", setup_projectors=True) | pawpyseed.core.noncollinear.NCLWavefunction | static
get_c_projectors_from_pps(self, pps) | pawpyseed.core.wavefunction.Wavefunction |
get_kpt_mapping(self, allkpts, symprec=1e-5, gen_trsym=True) | pawpyseed.core.wavefunction.Wavefunction |
get_nosym_kpoints(self, init_kpts=None, symprec=1e-5, gen_trsym=True, fil_trsym=True) | pawpyseed.core.wavefunction.Wavefunction |
get_state_realspace(self, b, k, s, dim=None) | pawpyseed.core.wavefunction.Wavefunction |
get_symmops(self, symprec) | pawpyseed.core.wavefunction.Wavefunction |
kpts(self) | pawpyseed.core.wavefunction.Wavefunction |
kws(self) | pawpyseed.core.wavefunction.Wavefunction |
make_c_projectors(self) | pawpyseed.core.wavefunction.Wavefunction |
nband | pawpyseed.core.noncollinear.NCLWavefunction |
nosym_kpts | pawpyseed.core.wavefunction.Wavefunction |
nspin | pawpyseed.core.noncollinear.NCLWavefunction |
num_proj_els | pawpyseed.core.noncollinear.NCLWavefunction |
nums | pawpyseed.core.noncollinear.NCLWavefunction |
nwk | pawpyseed.core.noncollinear.NCLWavefunction |
op_nums | pawpyseed.core.wavefunction.Wavefunction |
orig_kptnums | pawpyseed.core.wavefunction.Wavefunction |
projector_list | pawpyseed.core.noncollinear.NCLWavefunction |
projector_owner | pawpyseed.core.noncollinear.NCLWavefunction |
pwf | pawpyseed.core.noncollinear.NCLWavefunction |
structure | pawpyseed.core.noncollinear.NCLWavefunction |
symmops | pawpyseed.core.wavefunction.Wavefunction |
write_density_realspace(self, filename="PYAECCAR", dim=None, return_wf=False) | pawpyseed.core.wavefunction.Wavefunction |
write_state_realspace(self, b, k, s, fileprefix="", dim=None) | pawpyseed.core.noncollinear.NCLWavefunction |
pawpyseed::core::wavefunction::Wavefunction.write_state_realspace(self, b, k, s, fileprefix="", dim=None, return_wf=False) | pawpyseed.core.wavefunction.Wavefunction |